==> io-7.2.6-sources.jar: com/itextpdf/io/font/cmap/CMapObject.java <==
/*

    This file is part of the iText (R) project.
    Copyright (c) 1998-2024 Apryse Group NV
    Authors: Bruno Lowagie, Paulo Soares, et al.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License version 3
    as published by the Free Software Foundation with the addition of the
    following permission added to Section 15 as permitted in Section 7(a):
    FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY
    ITEXT GROUP. ITEXT GROUP DISCLAIMS THE WARRANTY OF NON INFRINGEMENT
    OF THIRD PARTY RIGHTS

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU Affero General Public License for more details.
    You should have received a copy of the GNU Affero General Public License
    along with this program; if not, see http://www.gnu.org/licenses or write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA, 02110-1301 USA, or download the license from the following URL:
    http://itextpdf.com/terms-of-use/

    The interactive user interfaces in modified source and object code versions
    of this program must display Appropriate Legal Notices, as required under
    Section 5 of the GNU Affero General Public License.

    In accordance with Section 7(b) of the GNU Affero General Public License,
    a covered work must retain the producer line in every PDF that is created
    or manipulated using iText.

    You can be released from the requirements of the license by purchasing
    a commercial license. Buying such a license is mandatory as soon as you
    develop commercial activities involving the iText software without
    disclosing the source code of your own applications.
    These activities include: offering paid services to customers as an ASP,
    serving PDFs on the fly in a web application, shipping iText with a closed
    source product.

    For more information, please contact iText Software Corp. at this
    address: sales@itextpdf.com
 */
package com.itextpdf.io.font.cmap;

public class CMapObject {

    protected static final int STRING = 1;
    protected static final int HEX_STRING = 2;
    protected static final int NAME = 3;
    protected static final int NUMBER = 4;
    protected static final int LITERAL = 5;
    protected static final int ARRAY = 6;
    protected static final int DICTIONARY = 7;
    protected static final int TOKEN = 8;

    private int type;
    private Object value;

    public CMapObject(int objectType, Object value) {
        this.type = objectType;
        this.value = value;
    }

    public Object getValue() {
        return value;
    }

    public int getType() {
        return type;
    }

    public void setValue(Object value) {
        this.value = value;
    }

    public boolean isString() {
        return type == STRING || type == HEX_STRING;
    }

    public boolean isHexString() {
        return type == HEX_STRING;
    }

    public boolean isName() {
        return type == NAME;
    }

    public boolean isNumber() {
        return type == NUMBER;
    }

    public boolean isLiteral() {
        return type == LITERAL;
    }

    public boolean isArray() {
        return type == ARRAY;
    }

    public boolean isDictionary() {
        return type == DICTIONARY;
    }

    public boolean isToken() {
        return type == TOKEN;
    }

    /**
     * Return String representation of {@code value} field.
     */
    @Override
    public String toString() {
        if (type == STRING || type == HEX_STRING) {
            byte[] content = (byte[]) value;
            StringBuilder str = new StringBuilder(content.length);
            for (byte b: content) {
                str.append((char)(b & 0xff));
            }
            return str.toString();
        }
        return value.toString();
    }

    public byte[] toHexByteArray() {
        if (type == HEX_STRING) {
            return (byte[])value;
        } else {
            return null;
        }
    }
}

==> io-8.0.2-sources.jar: com/itextpdf/io/font/cmap/CMapObject.java <==
/*
    This file is part of the iText (R) project.
    Copyright (c) 1998-2023 Apryse Group NV
    Authors: Apryse Software.

    This program is offered under a commercial and under the AGPL license.
    For commercial licensing, contact us at https://itextpdf.com/sales.  For AGPL licensing, see below.

    AGPL licensing:
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.itextpdf.io.font.cmap;

public class CMapObject {

    protected static final int STRING = 1;
    protected static final int HEX_STRING = 2;
    protected static final int NAME = 3;
    protected static final int NUMBER = 4;
    protected static final int LITERAL = 5;
    protected static final int ARRAY = 6;
    protected static final int DICTIONARY = 7;
    protected static final int TOKEN = 8;

    private int type;
    private Object value;

    public CMapObject(int objectType, Object value) {
        this.type = objectType;
        this.value = value;
    }

    public Object getValue() {
        return value;
    }

    public int getType() {
        return type;
    }

    public void setValue(Object value) {
        this.value = value;
    }

    public boolean isString() {
        return type == STRING || type == HEX_STRING;
    }

    public boolean isHexString() {
        return type == HEX_STRING;
    }

    public boolean isName() {
        return type == NAME;
    }

    public boolean isNumber() {
        return type == NUMBER;
    }

    public boolean isLiteral() {
        return type == LITERAL;
    }

    public boolean isArray() {
        return type == ARRAY;
    }

    public boolean isDictionary() {
        return type == DICTIONARY;
    }

    public boolean isToken() {
        return type == TOKEN;
    }

    /**
     * Return String representation of {@code value} field.
     */
    @Override
    public String toString() {
        if (type == STRING || type == HEX_STRING) {
            byte[] content = (byte[]) value;
            StringBuilder str = new StringBuilder(content.length);
            for (byte b: content) {
                str.append((char)(b & 0xff));
            }
            return str.toString();
        }
        return value.toString();
    }

    public byte[] toHexByteArray() {
        if (type == HEX_STRING) {
            return (byte[])value;
        } else {
            return null;
        }
    }
}
